<!-- TABLE OF CONTENTS -->
## Table of Contents

* [About the Project](#about-the-project)
  * [Built With](#built-with)
* [Getting Started](#getting-started)
  * [Prerequisites](#prerequisites)
  * [Installation](#installation)
* [Usage](#usage)
* [License](#license)
* [Contact](#contact)


<!-- LICENSE -->
## License

Distributed under the MIT License. See `LICENSE` for more information.


<!-- CONTACT -->
## Contact

Nirabhra Tapaswi - nirabhratapaswi@gmail.com

Project Link: [https://github.com/nirabhratapaswi/nShells](https://github.com/nirabhratapaswi/nShells)
Pip Link: [https://pypi.org/project/note-shell/](https://pypi.org/project/note-shell/)
